==> chaosmesh-model-5.0.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/ScheduleStatusFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ScheduleStatusFluentImpl<A extends ScheduleStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ScheduleStatusFluent<A> {

    private String nextRecover;
    private String nextStart;

    public ScheduleStatusFluentImpl() {
    }

    public ScheduleStatusFluentImpl(ScheduleStatus instance) {
        this.withNextRecover(instance.getNextRecover()); 
        this.withNextStart(instance.getNextStart()); 
    }

    public String getNextRecover() {
        return this.nextRecover;
    }

    public A withNextRecover(String nextRecover) {
        this.nextRecover=nextRecover; return (A) this;
    }

    public Boolean hasNextRecover() {
        return this.nextRecover != null;
    }

    public A withNewNextRecover(String arg1) {
        return (A)withNextRecover(new String(arg1));
    }

    public A withNewNextRecover(StringBuilder arg1) {
        return (A)withNextRecover(new String(arg1));
    }

    public A withNewNextRecover(StringBuffer arg1) {
        return (A)withNextRecover(new String(arg1));
    }

    public String getNextStart() {
        return this.nextStart;
    }

    public A withNextStart(String nextStart) {
        this.nextStart=nextStart; return (A) this;
    }

    public Boolean hasNextStart() {
        return this.nextStart != null;
    }

    public A withNewNextStart(String arg1) {
        return (A)withNextStart(new String(arg1));
    }

    public A withNewNextStart(StringBuilder arg1) {
        return (A)withNextStart(new String(arg1));
    }

    public A withNewNextStart(StringBuffer arg1) {
        return (A)withNextStart(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ScheduleStatusFluentImpl that = (ScheduleStatusFluentImpl) o;
        if (nextRecover != null ? !nextRecover.equals(that.nextRecover) :that.nextRecover != null) return false;
        if (nextStart != null ? !nextStart.equals(that.nextStart) :that.nextStart != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(nextRecover,  nextStart,  super.hashCode());
    }

}

==> chaosmesh-model-5.3.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/ScheduleStatusFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ScheduleStatusFluentImpl<A extends ScheduleStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ScheduleStatusFluent<A> {

    private String nextRecover;
    private String nextStart;

    public ScheduleStatusFluentImpl() {
    }

    public ScheduleStatusFluentImpl(ScheduleStatus instance) {
        this.withNextRecover(instance.getNextRecover()); 
        this.withNextStart(instance.getNextStart()); 
    }

    public String getNextRecover() {
        return this.nextRecover;
    }

    public A withNextRecover(String nextRecover) {
        this.nextRecover=nextRecover; return (A) this;
    }

    public Boolean hasNextRecover() {
        return this.nextRecover != null;
    }

    public A withNewNextRecover(StringBuilder arg1) {
        return (A)withNextRecover(new String(arg1));
    }

    public A withNewNextRecover(int[] arg1,int arg2,int arg3) {
        return (A)withNextRecover(new String(arg1, arg2, arg3));
    }

    public A withNewNextRecover(char[] arg1) {
        return (A)withNextRecover(new String(arg1));
    }

    public A withNewNextRecover(StringBuffer arg1) {
        return (A)withNextRecover(new String(arg1));
    }

    public A withNewNextRecover(byte[] arg1,int arg2) {
        return (A)withNextRecover(new String(arg1, arg2));
    }

    public A withNewNextRecover(byte[] arg1) {
        return (A)withNextRecover(new String(arg1));
    }

    public A withNewNextRecover(char[] arg1,int arg2,int arg3) {
        return (A)withNextRecover(new String(arg1, arg2, arg3));
    }

    public A withNewNextRecover(byte[] arg1,int arg2,int arg3) {
        return (A)withNextRecover(new String(arg1, arg2, arg3));
    }

    public A withNewNextRecover(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withNextRecover(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewNextRecover(String arg1) {
        return (A)withNextRecover(new String(arg1));
    }

    public String getNextStart() {
        return this.nextStart;
    }

    public A withNextStart(String nextStart) {
        this.nextStart=nextStart; return (A) this;
    }

    public Boolean hasNextStart() {
        return this.nextStart != null;
    }

    public A withNewNextStart(StringBuilder arg1) {
        return (A)withNextStart(new String(arg1));
    }

    public A withNewNextStart(int[] arg1,int arg2,int arg3) {
        return (A)withNextStart(new String(arg1, arg2, arg3));
    }

    public A withNewNextStart(char[] arg1) {
        return (A)withNextStart(new String(arg1));
    }

    public A withNewNextStart(StringBuffer arg1) {
        return (A)withNextStart(new String(arg1));
    }

    public A withNewNextStart(byte[] arg1,int arg2) {
        return (A)withNextStart(new String(arg1, arg2));
    }

    public A withNewNextStart(byte[] arg1) {
        return (A)withNextStart(new String(arg1));
    }

    public A withNewNextStart(char[] arg1,int arg2,int arg3) {
        return (A)withNextStart(new String(arg1, arg2, arg3));
    }

    public A withNewNextStart(byte[] arg1,int arg2,int arg3) {
        return (A)withNextStart(new String(arg1, arg2, arg3));
    }

    public A withNewNextStart(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withNextStart(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewNextStart(String arg1) {
        return (A)withNextStart(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ScheduleStatusFluentImpl that = (ScheduleStatusFluentImpl) o;
        if (nextRecover != null ? !nextRecover.equals(that.nextRecover) :that.nextRecover != null) return false;
        if (nextStart != null ? !nextStart.equals(that.nextStart) :that.nextStart != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(nextRecover,  nextStart,  super.hashCode());
    }

}
